Highmaps Example

1 | NEBRASKA | 2.6
2 | NORTH DAKOTA | 3.1
3 | UTAH | 3.5
4 | VERMONT | 3.6
5 | IOWA | 3.8
5 | MINNESOTA | 3.8
5 | NEW HAMPSHIRE | 3.8
5 | SOUTH DAKOTA | 3.8
9 | IDAHO | 3.9
9 | MONTANA | 3.9
11 | HAWAII | 4.1
11 | WYOMING | 4.1
13 | COLORADO | 4.3
13 | OKLAHOMA | 4.3
13 | TEXAS | 4.3
16 | KANSAS | 4.4
17 | DELAWARE | 4.6
17 | MASSACHUSETTS | 4.6
17 | WISCONSIN | 4.6
20 | MAINE | 4.7
21 | VIRGINIA | 4.9
22 | INDIANA | 5.1
22 | KENTUCKY | 5.1
24 | OHIO | 5.2
25 | MARYLAND | 5.3
25 | OREGON | 5.3
27 | PENNSYLVANIA | 5.4
27 | WASHINGTON | 5.4
29 | MICHIGAN | 5.5
30 | ARKANSAS | 5.7
30 | FLORIDA | 5.7
30 | NEW YORK | 5.7
30 | NORTH CAROLINA | 5.7
34 | ARIZONA | 5.8
34 | MISSOURI | 5.8
34 | TENNESSEE | 5.8
37 | RHODE ISLAND | 5.9
38 | CONNECTICUT | 6.0
38 | ILLINOIS | 6.0
40 | ALABAMA | 6.1
41 | NEW MEXICO | 6.2
42 | GEORGIA | 6.3
43 | CALIFORNIA | 6.4
44 | NEW JERSEY | 6.5
45 | LOUISIANA | 6.6
46 | MISSISSIPPI | 6.7
47 | ALASKA | 6.8
47 | SOUTH CAROLINA | 6.8
49 | NEVADA | 7.0
50 | WEST VIRGINIA | 7.2
51 | DISTRICT OF COLUMBIA | 7.3